@@ -52,6 +52,11 @@
 #include <libgnome/gnome-program.h>
 #include <libgnome/gnome-util.h>
 
+#if defined(__APPLE__) && defined(HAVE_NSGETENVIRON) && defined(HAVE_CRT_EXTERNS_H)
+# include <crt_externs.h>
+# define environ (*_NSGetEnviron())
+#endif
+
 /**
  * gnome_util_user_shell:
  *
@@ -72,7 +77,7 @@ gnome_util_user_shell (void)
 		"/bin/zsh", "/usr/bin/zsh",
 		"/bin/tcsh", "/usr/bin/tcsh",
 		"/bin/ksh", "/usr/bin/ksh",
-		"/bin/csh", "/bin/sh", 0
+		"/bin/csh", "/bin/sh", NULL
 	};
 
 	if (geteuid () == getuid () &&
